
from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationTags, DeviceOnlineEvent, AnnotationMetadata, DeviceOfflineEventTags, EventTriggerCommand, EventSortOrder, LabeledPolygon, StatefulEvent, DeviceOfflineEventSeverity, DeviceOfflineEventStreamType, InterventionRequestTags, SystemEventMetadata, StatefulEventMetadata, PortForwardingSessionRecordStreamType, CustomEvent, Label, EventQuerySeveritiesItem, CustomEventSeverity, EventQuery, DeviceOnlineEventType, DatapointEventType, CommandDeliveryEventStreamType, EventHistogramEntry, CommentMetadata, Annotation, CustomEventMetadata, DeviceOfflineEvent, TaskSummaryMetadata, EventQueryEventTypesItem, DeviceOnlineEventTags, StatefulEventSeverity, EventSeekQueryEventTypesItem, EventCounts, CommentStreamType, TaskSummaryStreamType, StatefulEventTags, TaskSummaryTags, CustomEventType, StatefulEventStreamType, EventSort, DatapointEventSeverity, CommentType, TeleopSessionRecordType, CommandDeliveryEventMetadata, EventSeekQueryTypesItem, DeviceOfflineEventType, DatapointEventTags, EventSeekQuerySeveritiesItem, DatapointEventMetadata, InterventionRequestType, EventSeekQuery, EventFilterSeveritiesItem, Comment, TeleopSessionRecord, EventSeekQueryDirection, DeviceOnlineEventMetadata, DatapointEvent, CommandDeliveryEventType, CustomEventStreamType, InterventionRequest, CommentTags, EventListResponse, AnnotationType, AnnotationStreamType, EventFilterTypesItem, EventExportSheetRequest, PortForwardingSessionRecordMetadata, SystemEventType, TaskSummaryType, PortForwardingSessionRecordType, EventFilterEventTypesItem, PhysicalRequestData, PortForwardingSessionRecordTags, DatapointEventStreamType, EventQueryTypesItem, SystemEventTags, SystemEventStreamType, DeviceOfflineEventMetadata, InterventionRequestStreamType, TeleopSessionRecordStreamType, EventExportSheetResult, EventHistogram, TeleopRequestData, InterventionRequestSeverity, EventSortColumn, CustomEventTags, TeleopSessionRecordMetadata, StatefulEventType, SelectionRequestData, CommandDeliveryEvent, InterventionRequestInterventionType, CommandDeliveryEventTags, TaskSummary, PortForwardingSessionRecord, DeviceOnlineEventStreamType, EventFilter, TeleopSessionRecordTags, InterventionRequestMetadata, LabelingRequestData, SystemEvent, DeviceOnlineEventSeverity
from formant.sdk.cloud.v2.formant_admin_api_client.api.event import event_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar

import attr

T = TypeVar("T", bound="ToolDescription")


@attr.s(auto_attribs=True)
class ToolDescription:
    """
    Attributes:
        name (str):
        prompt (str):
        description (str):
        model (str):
    """

    name: str
    prompt: str
    description: str
    model: str
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        prompt = self.prompt
        description = self.description
        model = self.model

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "name": name,
                "prompt": prompt,
                "description": description,
                "model": model,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("name")

        prompt = d.pop("prompt")

        description = d.pop("description")

        model = d.pop("model")

        tool_description = cls(
            name=name,
            prompt=prompt,
            description=description,
            model=model,
        )

        tool_description.additional_properties = d
        return tool_description

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import AnnotationTags, Annotation, AnnotationField, AnnotationMetadata, UserParameters, AnnotationFieldValue, AnnotationTemplateTags, ScopeFilter, TagParameters, AnnotationFieldType, AnnotationFieldValuesRequest, AnnotationFieldValuesRequestTags, UserParametersRolesItem, AnnotationFieldValuesResponse, ScopeFilterTypesItem, SheetParameters, AnnotationTemplate, AnnotationType, AnnotationFieldValueTags, AnnotationStreamType, AnnotationTemplateListResponse
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation import annotation_controller_post
from formant.sdk.cloud.v2.formant_admin_api_client.api.annotation_template import annotation_template_controller_list, annotation_template_controller_get_one
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.user_teleop_ros_stream_configuration import UserTeleopRosStreamConfiguration


T = TypeVar("T", bound="UserTeleopConfiguration")


@attr.s(auto_attribs=True)
class UserTeleopConfiguration:
    """
    Attributes:
        ros_streams (Union[Unset, List['UserTeleopRosStreamConfiguration']]):
    """

    ros_streams: Union[Unset, List["UserTeleopRosStreamConfiguration"]] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        ros_streams: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.ros_streams, Unset):
            ros_streams = []
            for ros_streams_item_data in self.ros_streams:
                ros_streams_item = ros_streams_item_data.to_dict()

                ros_streams.append(ros_streams_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ros_streams is not UNSET:
            field_dict["rosStreams"] = ros_streams

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.user_teleop_ros_stream_configuration import UserTeleopRosStreamConfiguration

        d = src_dict.copy()
        ros_streams = []
        _ros_streams = d.pop("rosStreams", UNSET)
        for ros_streams_item_data in _ros_streams or []:
            ros_streams_item = UserTeleopRosStreamConfiguration.from_dict(ros_streams_item_data)

            ros_streams.append(ros_streams_item)

        user_teleop_configuration = cls(
            ros_streams=ros_streams,
        )

        user_teleop_configuration.additional_properties = d
        return user_teleop_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union

import attr
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="PartialGroup")


@attr.s(auto_attribs=True)
class PartialGroup:
    """
    Attributes:
        organization_id (Union[Unset, str]):
        name (Union[Unset, str]):
        tag_key (Union[Unset, Any]):
        tag_value (Union[Unset, Any]):
        active (Union[Unset, bool]):
        enabled (Union[Unset, bool]):
        color (Union[Unset, None, str]):
        parent (Union[Unset, None, str]):
        id (Union[Unset, str]):
        created_at (Union[Unset, datetime.datetime]):
        updated_at (Union[Unset, datetime.datetime]):
    """

    organization_id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    tag_key: Union[Unset, Any] = UNSET
    tag_value: Union[Unset, Any] = UNSET
    active: Union[Unset, bool] = UNSET
    enabled: Union[Unset, bool] = UNSET
    color: Union[Unset, None, str] = UNSET
    parent: Union[Unset, None, str] = UNSET
    id: Union[Unset, str] = UNSET
    created_at: Union[Unset, datetime.datetime] = UNSET
    updated_at: Union[Unset, datetime.datetime] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        organization_id = self.organization_id
        name = self.name
        tag_key = self.tag_key
        tag_value = self.tag_value
        active = self.active
        enabled = self.enabled
        color = self.color
        parent = self.parent
        id = self.id
        created_at: Union[Unset, str] = UNSET
        if not isinstance(self.created_at, Unset):
            created_at = self.created_at.isoformat()

        updated_at: Union[Unset, str] = UNSET
        if not isinstance(self.updated_at, Unset):
            updated_at = self.updated_at.isoformat()

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if organization_id is not UNSET:
            field_dict["organizationId"] = organization_id
        if name is not UNSET:
            field_dict["name"] = name
        if tag_key is not UNSET:
            field_dict["tagKey"] = tag_key
        if tag_value is not UNSET:
            field_dict["tagValue"] = tag_value
        if active is not UNSET:
            field_dict["active"] = active
        if enabled is not UNSET:
            field_dict["enabled"] = enabled
        if color is not UNSET:
            field_dict["color"] = color
        if parent is not UNSET:
            field_dict["parent"] = parent
        if id is not UNSET:
            field_dict["id"] = id
        if created_at is not UNSET:
            field_dict["createdAt"] = created_at
        if updated_at is not UNSET:
            field_dict["updatedAt"] = updated_at

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        organization_id = d.pop("organizationId", UNSET)

        name = d.pop("name", UNSET)

        tag_key = d.pop("tagKey", UNSET)

        tag_value = d.pop("tagValue", UNSET)

        active = d.pop("active", UNSET)

        enabled = d.pop("enabled", UNSET)

        color = d.pop("color", UNSET)

        parent = d.pop("parent", UNSET)

        id = d.pop("id", UNSET)

        _created_at = d.pop("createdAt", UNSET)
        created_at: Union[Unset, datetime.datetime]
        if isinstance(_created_at, Unset):
            created_at = UNSET
        else:
            created_at = isoparse(_created_at)

        _updated_at = d.pop("updatedAt", UNSET)
        updated_at: Union[Unset, datetime.datetime]
        if isinstance(_updated_at, Unset):
            updated_at = UNSET
        else:
            updated_at = isoparse(_updated_at)

        partial_group = cls(
            organization_id=organization_id,
            name=name,
            tag_key=tag_key,
            tag_value=tag_value,
            active=active,
            enabled=enabled,
            color=color,
            parent=parent,
            id=id,
            created_at=created_at,
            updated_at=updated_at,
        )

        partial_group.additional_properties = d
        return partial_group

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import Adapter, AdapterConfiguration, AdapterCascadingConfiguration, AdapterCascadingConfigurationListResponse, AdapterListResponse, AdapterCascadingConfigurationType, AdapterCascadingConfigurationSpecificity
from formant.sdk.cloud.v2.formant_admin_api_client.api.adapter import adapter_controller_post, adapter_controller_delete
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from typing import Any




from formant.sdk.cloud.v2.formant_admin_api_client.models import LocationViewConfiguration, ViewListResponse, ImageViewConfiguration, ViewLayoutType, BitsetViewConfiguration, ViewTags, ViewConfigurationType, NumericViewConfiguration, LocationViewport, LocationViewConfigurationBasemap, Location, ViewConfiguration, Filter, PartialViewTags, ImageViewConfigurationMode, LocalizationViewConfiguration, PartialView, TransformTreeViewConfiguration, PartialViewLayoutType, Vector3, Camera, PointCloudViewConfiguration, View
from formant.sdk.cloud.v2.formant_admin_api_client.api.view import view_controller_get_one, view_controller_get_all, view_controller_patch
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.image_view_configuration_mode import ImageViewConfigurationMode
from ..types import UNSET, Unset

T = TypeVar("T", bound="ImageViewConfiguration")


@attr.s(auto_attribs=True)
class ImageViewConfiguration:
    """
    Attributes:
        mode (Union[Unset, ImageViewConfigurationMode]):
    """

    mode: Union[Unset, ImageViewConfigurationMode] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        mode: Union[Unset, str] = UNSET
        if not isinstance(self.mode, Unset):
            mode = self.mode.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if mode is not UNSET:
            field_dict["mode"] = mode

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _mode = d.pop("mode", UNSET)
        mode: Union[Unset, ImageViewConfigurationMode]
        if isinstance(_mode, Unset):
            mode = UNSET
        else:
            mode = ImageViewConfigurationMode(_mode)

        image_view_configuration = cls(
            mode=mode,
        )

        image_view_configuration.additional_properties = d
        return image_view_configuration

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties




from formant.sdk.cloud.v2.formant_admin_api_client.models import DeviceOnlineEvent, PartialDevice, DeviceOfflineEventTags, DeviceScope, DeviceStreamHardwareConfigurationQuality, DeviceTeleopHardwareStreamConfigurationHardwareType, DeviceStreamFileTailConfiguration, OnDemandState, CommandProgress, DeviceTeleopConfiguration, OnDemandBufferBufferType, DeviceOfflineEventSeverity, DeviceOfflineEventStreamType, DeviceStreamCustomConfiguration, ScopeFilter, DeviceStreamDirectoryWatchConfiguration, DeviceStreamRosLocalizationConfigurationType, RtcInfo, DeviceStreamDirectoryWatchConfigurationType, OnDemandPresenceTimeRange, DeviceConfigurationDocumentTags, DeviceListResponse, DeviceConfiguration, DeviceTelemetryConfiguration, TeleopJoystickConfiguration, DeviceTeleopRosStreamConfigurationAudioCodec, OnvifDevice, DeviceOnlineEventType, DeviceStreamRosTopicConfiguration, DeviceStreamCustomConfigurationType, DeviceScopeTypesItem, OnDemandPresenceStreamItemGroup, OsInfo, DeviceStreamHardwareConfigurationHardwareType, DeviceDetailsTags, DeviceConfigurationDocument, DeviceOfflineEvent, DeviceTeleopCustomStreamConfigurationNumericControlVisualization, DeviceOnlineEventTags, RtcInfoRtcIceTransportPoliciesItem, AudioDevice, DeviceStreamRosLocalizationConfiguration, DeviceStreamRosTransformTreeConfigurationType, TeleopJoystickAxisConfiguration, ValidationConfiguration, OnDemandStreamPresence, RosTopic, HwInfo, OnDemandPresenceStreamItemGroupDatapointType, DeviceType, DeviceTeleopHardwareStreamConfigurationRtcStreamType, DeviceDiagnosticsConfiguration, DeviceStreamHardwareConfiguration, DeviceDiskConfiguration, DeviceTeleopHardwareStreamConfigurationQuality, DeviceStreamConfiguration, DeviceTeleopCustomStreamConfigurationQuality, DeviceRosState, KernelInfo, TeleopViewConfiguration, DeviceOfflineEventType, DeviceTeleopCustomStreamConfigurationRtcStreamType, DeviceTags, NodeInfo, RtcInfoRtcIceServerProtocol, DeviceTeleopRosStreamConfigurationMode, DeviceResourcesConfiguration, DeviceStateEnv, PartialDeviceType, PartialDeviceTags, DeviceTeleopRosStreamConfiguration, DeviceStreamFileTailConfigurationFileFormat, DeviceOnlineEventMetadata, DeviceApplicationConfiguration, DeviceCredentials, DeviceTeleopHardwareStreamConfigurationMode, DeviceStreamRosTransformTreeConfiguration, DeviceState, DevicePortForwardingConfiguration, DeviceProvisioningRequest, DeviceDetailsType, DeviceStreamHardwareConfigurationType, DeviceRosConfiguration, DeviceQuery, DeviceTeleopRosStreamConfigurationQuality, AdapterConfiguration, DeviceConfigurationTemplate, OnDemandBuffer, DeviceDetailsListResponse, DeviceBlobData, DeviceConfigurationTemplateListResponse, DeviceReportedConfigurationState, DeviceTeleopHardwareStreamConfiguration, DeviceApplicationConfigurationConfigurationMap, DeviceStreamConfigurationTags, DeviceConfigurationTemplateTags, DeviceStreamRosTopicConfigurationType, DeviceOfflineEventMetadata, DeviceTeleopCustomStreamConfiguration, DeviceDetails, NetworkInfo, DeviceTeleopRosStreamConfigurationTopicType, DeviceTeleopRosStreamConfigurationNumericControlVisualization, Device, DeviceFollower, ScopeFilterTypesItem, TeleopJoystickAxisConfigurationDimension, DeviceQueryType, TeleopJoystickConfigurationPosition, VideoDevice, DeviceStreamDirectoryWatchConfigurationFileType, Network, DeviceProvisioning, DeviceOnlineEventStreamType, DeviceTeleopCustomStreamConfigurationMode, DeviceStreamTransformConfiguration, DeviceStreamConfigurationQuality, DeviceOnlineEventSeverity, DeviceStreamFileTailConfigurationType
from formant.sdk.cloud.v2.formant_admin_api_client.api.device import device_controller_query, device_controller_patch, device_controller_get_one, device_controller_get_configuration, device_controller_post_configuration
from formant.sdk.cloud.v2.formant_admin_api_client.types import *
from formant.sdk.cloud.v2.formant_admin_api_client.types import Optional




from formant.sdk.cloud.v2.formant_admin_api_client.models import CommandResponseTags, CommandDeliveryEventStreamType, CommandTags, CommandResponse, CommandTemplateParameterMeta, CommandListResponse, CommandProgress, CommandResponseStreamType, CommandRequest, CommandTemplateTags, ScopeFilter, CommandRequestListResponse, ScopeFilterTypesItem, CommandParameterMeta, CommandQuery, CommandDeliveryEventType, FileInfo, CommandStreamType, CommandDeliveryEvent, CommandTemplate, CommandDeliveryEventTags, CommandParameter, Command, CommandTemplateListResponse, CommandDeliveryEventMetadata
from formant.sdk.cloud.v2.formant_admin_api_client.api.command import command_controller_post, command_controller_query
from formant.sdk.cloud.v2.formant_admin_api_client.types import *



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.stream_column_aggregate_type import StreamColumnAggregateType
from ..models.stream_column_stream_type import StreamColumnStreamType
from ..types import UNSET, Unset

T = TypeVar("T", bound="StreamColumn")


@attr.s(auto_attribs=True)
class StreamColumn:
    """
    Attributes:
        stream_name (str):
        stream_type (StreamColumnStreamType):
        aggregate_type (Union[Unset, StreamColumnAggregateType]):
    """

    stream_name: str
    stream_type: StreamColumnStreamType
    aggregate_type: Union[Unset, StreamColumnAggregateType] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        stream_name = self.stream_name
        stream_type = self.stream_type.value

        aggregate_type: Union[Unset, str] = UNSET
        if not isinstance(self.aggregate_type, Unset):
            aggregate_type = self.aggregate_type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "streamName": stream_name,
                "streamType": stream_type,
            }
        )
        if aggregate_type is not UNSET:
            field_dict["aggregateType"] = aggregate_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        stream_name = d.pop("streamName")

        stream_type = StreamColumnStreamType(d.pop("streamType"))

        _aggregate_type = d.pop("aggregateType", UNSET)
        aggregate_type: Union[Unset, StreamColumnAggregateType]
        if isinstance(_aggregate_type, Unset):
            aggregate_type = UNSET
        else:
            aggregate_type = StreamColumnAggregateType(_aggregate_type)

        stream_column = cls(
            stream_name=stream_name,
            stream_type=stream_type,
            aggregate_type=aggregate_type,
        )

        stream_column.additional_properties = d
        return stream_column

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
